@@ -1,55 +1,66 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="zh_CN">
+<TS version="2.0" language="zh_CN">
 <context>
     <name>AuthDialog</name>
     <message>
         <source>More Devices</source>
-        <translation type="vanished">选择其他设备</translation>
+        <translation type="obsolete">选择其他设备</translation>
     </message>
     <message>
         <source>Biometric</source>
-        <translation type="vanished">使用生物识别认证</translation>
+        <translation type="obsolete">使用生物识别认证</translation>
     </message>
     <message>
         <source>Password</source>
-        <translation type="vanished">使用密码认证</translation>
+        <translation type="obsolete">使用密码认证</translation>
     </message>
     <message>
-        <location filename="../src/authdialog.cpp" line="370"/>
+        <location filename="../src/authdialog.cpp" line="486"/>
         <source>Retry</source>
         <translation>重试</translation>
     </message>
     <message>
         <source>UnLock</source>
-        <translation type="vanished">解锁</translation>
+        <translation type="obsolete">解锁</translation>
     </message>
     <message>
         <source>LoggedIn</source>
-        <translation type="vanished">已登录</translation>
+        <translation type="obsolete">已登录</translation>
     </message>
     <message>
-        <location filename="../src/authdialog.cpp" line="169"/>
+        <location filename="../src/authdialog.cpp" line="248"/>
         <source>Password: </source>
         <translation>密码：</translation>
     </message>
     <message>
-        <location filename="../src/authdialog.cpp" line="184"/>
+        <location filename="../src/authdialog.cpp" line="268"/>
+        <location filename="../src/authdialog.cpp" line="299"/>
+        <source>Account locked %1 minutes due to %2 fail attempts</source>
+        <translation>账户锁定%1分钟由于%2次错误尝试</translation>
+    </message>
+    <message>
+        <location filename="../src/authdialog.cpp" line="281"/>
         <source>Password Incorrect, Please try again</source>
         <translation>密码错误，请重试</translation>
     </message>
     <message>
-        <location filename="../src/authdialog.cpp" line="336"/>
+        <location filename="../src/authdialog.cpp" line="295"/>
+        <source>Authentication failure,there are still %1 remaining opportunities</source>
+        <translation>认证失败，还剩%1次尝试机会</translation>
+    </message>
+    <message>
+        <location filename="../src/authdialog.cpp" line="452"/>
         <source>Biometric Authentication</source>
         <translation>生物识别认证</translation>
     </message>
     <message>
-        <location filename="../src/authdialog.cpp" line="348"/>
+        <location filename="../src/authdialog.cpp" line="464"/>
         <source>Password Authentication</source>
         <translation>密码认证</translation>
     </message>
     <message>
-        <location filename="../src/authdialog.cpp" line="360"/>
+        <location filename="../src/authdialog.cpp" line="476"/>
         <source>Other Devices</source>
         <translation>其他设备</translation>
     </message>
@@ -58,49 +69,49 @@
     <name>BioDevices</name>
     <message>
         <source>FingerPrint</source>
-        <translation type="vanished">指纹</translation>
+        <translation type="obsolete">指纹</translation>
     </message>
     <message>
         <source>FingerVein</source>
-        <translation type="vanished">指静脉</translation>
+        <translation type="obsolete">指静脉</translation>
     </message>
     <message>
         <source>Iris</source>
-        <translation type="vanished">虹膜</translation>
+        <translation type="obsolete">虹膜</translation>
     </message>
     <message>
         <source>Face</source>
-        <translation type="vanished">人脸</translation>
+        <translation type="obsolete">人脸</translation>
     </message>
     <message>
         <source>VoicePrint</source>
-        <translation type="vanished">声纹</translation>
+        <translation type="obsolete">声纹</translation>
     </message>
 </context>
 <context>
     <name>BioDevicesWidget</name>
     <message>
         <source>Please select other biometric devices</source>
-        <translation type="vanished">请选择其他生物识别设备</translation>
+        <translation type="obsolete">请选择其他生物识别设备</translation>
     </message>
     <message>
         <source>Device Type:</source>
-        <translation type="vanished">设备类型：</translation>
+        <translation type="obsolete">设备类型：</translation>
     </message>
     <message>
         <source>Device Name:</source>
-        <translation type="vanished">设备名称：</translation>
+        <translation type="obsolete">设备名称：</translation>
     </message>
 </context>
 <context>
     <name>BiometricAuthWidget</name>
     <message>
-        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="74"/>
+        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="96"/>
         <source>Current device: </source>
         <translation>当前设备：</translation>
     </message>
     <message>
-        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="128"/>
+        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="152"/>
         <source>Identify failed, Please retry.</source>
         <translation>识别失败，请重试</translation>
     </message>
@@ -108,22 +119,22 @@
 <context>
     <name>BiometricDevicesWidget</name>
     <message>
-        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="29"/>
+        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="47"/>
         <source>Please select the biometric device</source>
         <translation>请选择生物设备</translation>
     </message>
     <message>
-        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="34"/>
+        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="52"/>
         <source>Device type:</source>
         <translation>设备类型：</translation>
     </message>
     <message>
-        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="48"/>
+        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="66"/>
         <source>Device name:</source>
         <translation>设备型号：</translation>
     </message>
     <message>
-        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="56"/>
+        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="74"/>
         <source>OK</source>
         <translation>确定</translation>
     </message>
@@ -131,27 +142,27 @@
 <context>
     <name>DeviceType</name>
     <message>
-        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="23"/>
+        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="41"/>
         <source>FingerPrint</source>
         <translation>指纹</translation>
     </message>
     <message>
-        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="25"/>
+        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="43"/>
         <source>FingerVein</source>
         <translation>指静脉</translation>
     </message>
     <message>
-        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="27"/>
+        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="45"/>
         <source>Iris</source>
         <translation>虹膜</translation>
     </message>
     <message>
-        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="29"/>
+        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="47"/>
         <source>Face</source>
         <translation>人脸</translation>
     </message>
     <message>
-        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="31"/>
+        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="49"/>
         <source>VoicePrint</source>
         <translation>声纹</translation>
     </message>
@@ -182,12 +193,12 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/lockwidget.cpp" line="130"/>
+        <location filename="../src/lockwidget.cpp" line="149"/>
         <source>Guest</source>
         <translation>游客</translation>
     </message>
     <message>
-        <location filename="../src/lockwidget.cpp" line="137"/>
+        <location filename="../src/lockwidget.cpp" line="156"/>
         <source>SwitchUser</source>
         <translation>切换用户</translation>
     </message>
@@ -201,17 +212,17 @@
     </message>
     <message>
         <location filename="../src/ukui-screensaver-command.cpp" line="35"/>
-        <location filename="../src/ukui-screensaver-dialog.cpp" line="53"/>
+        <location filename="../src/ukui-screensaver-dialog.cpp" line="96"/>
         <source>lock the screen immediately</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/ukui-screensaver-dialog.cpp" line="48"/>
+        <location filename="../src/ukui-screensaver-dialog.cpp" line="91"/>
         <source>Dialog for the ukui ScreenSaver.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/ukui-screensaver-dialog.cpp" line="55"/>
+        <location filename="../src/ukui-screensaver-dialog.cpp" line="98"/>
         <source>activated by session idle signal</source>
         <translation type="unfinished"></translation>
     </message>
